@@ -21,20 +21,27 @@ from __future__ import annotations
 import logging
 import random
 import time
-from typing import Callable, Dict, List
+from typing import Callable, cast
 
+from aiohttp import ClientSession
+from gcloud.aio.auth import AioSession, Token
 from googleapiclient.discovery import Resource, build
 from googleapiclient.errors import HttpError
+from httplib2 import Response
+from requests import Session
 
-from airflow.providers.google.common.hooks.base_google import GoogleBaseHook
+from airflow.exceptions import AirflowException
+from airflow.providers.google.common.hooks.base_google import GoogleBaseAsyncHook, GoogleBaseHook
 from airflow.version import version as airflow_version
 
 log = logging.getLogger(__name__)
 
-_AIRFLOW_VERSION = 'v' + airflow_version.replace('.', '-').replace('+', '-')
+_AIRFLOW_VERSION = "v" + airflow_version.replace(".", "-").replace("+", "-")
 
 
-def _poll_with_exponential_delay(request, execute_num_retries, max_n, is_done_func, is_error_func):
+def _poll_with_exponential_delay(
+    request, execute_num_retries, max_n, is_done_func, is_error_func
+) -> Response:
     """
     Execute request with exponential delay.
 
@@ -48,26 +55,25 @@ def _poll_with_exponential_delay(request, execute_num_retries, max_n, is_done_fu
     :param is_done_func: callable to determine if operation is done.
     :param is_error_func: callable to determine if operation is failed.
     :return: response
-    :rtype: httplib2.Response
     """
     for i in range(0, max_n):
         try:
             response = request.execute(num_retries=execute_num_retries)
             if is_error_func(response):
-                raise ValueError(f'The response contained an error: {response}')
+                raise ValueError(f"The response contained an error: {response}")
             if is_done_func(response):
-                log.info('Operation is done: %s', response)
+                log.info("Operation is done: %s", response)
                 return response
 
             time.sleep((2**i) + (random.randint(0, 1000) / 1000))
         except HttpError as e:
             if e.resp.status != 429:
-                log.info('Something went wrong. Not retrying: %s', format(e))
+                log.info("Something went wrong. Not retrying: %s", format(e))
                 raise
             else:
                 time.sleep((2**i) + (random.randint(0, 1000) / 1000))
 
-    raise ValueError(f'Connection could not be established after {max_n} retries.')
+    raise ValueError(f"Connection could not be established after {max_n} retries.")
 
 
 class MLEngineHook(GoogleBaseHook):
@@ -78,6 +84,14 @@ class MLEngineHook(GoogleBaseHook):
     keyword arguments rather than positional.
     """
 
+    def __init__(self, **kwargs):
+        if kwargs.get("delegate_to") is not None:
+            raise RuntimeError(
+                "The `delegate_to` parameter has been deprecated before and finally removed in this version"
+                " of Google Provider. You MUST convert it to `impersonate_chain`"
+            )
+        super().__init__(**kwargs)
+
     def get_conn(self) -> Resource:
         """
         Retrieves the connection to MLEngine.
@@ -85,7 +99,7 @@ class MLEngineHook(GoogleBaseHook):
         :return: Google MLEngine services object.
         """
         authed_http = self._authorize()
-        return build('ml', 'v1', http=authed_http, cache_discovery=False)
+        return build("ml", "v1", http=authed_http, cache_discovery=False)
 
     @GoogleBaseHook.fallback_to_default_project_id
     def create_job(self, job: dict, project_id: str, use_existing_job_fn: Callable | None = None) -> dict:
@@ -115,15 +129,14 @@ class MLEngineHook(GoogleBaseHook):
             we by default reuse the existing MLEngine job.
         :return: The MLEngine job object if the job successfully reach a
             terminal state (which might be FAILED or CANCELLED state).
-        :rtype: dict
         """
         hook = self.get_conn()
 
         self._append_label(job)
         self.log.info("Creating job.")
 
-        request = hook.projects().jobs().create(parent=f'projects/{project_id}', body=job)
-        job_id = job['jobId']
+        request = hook.projects().jobs().create(parent=f"projects/{project_id}", body=job)
+        job_id = job["jobId"]
 
         try:
             request.execute(num_retries=self.num_retries)
@@ -131,21 +144,55 @@ class MLEngineHook(GoogleBaseHook):
             # 409 means there is an existing job with the same job ID.
             if e.resp.status == 409:
                 if use_existing_job_fn is not None:
-                    existing_job = self._get_job(project_id, job_id)
+                    existing_job = self.get_job(project_id, job_id)
                     if not use_existing_job_fn(existing_job):
                         self.log.error(
-                            'Job with job_id %s already exist, but it does not match our expectation: %s',
+                            "Job with job_id %s already exist, but it does not match our expectation: %s",
                             job_id,
                             existing_job,
                         )
                         raise
-                self.log.info('Job with job_id %s already exist. Will waiting for it to finish', job_id)
+                self.log.info("Job with job_id %s already exist. Will waiting for it to finish", job_id)
             else:
-                self.log.error('Failed to create MLEngine job: %s', e)
+                self.log.error("Failed to create MLEngine job: %s", e)
                 raise
 
         return self._wait_for_job_done(project_id, job_id)
 
+    @GoogleBaseHook.fallback_to_default_project_id
+    def create_job_without_waiting_result(
+        self,
+        body: dict,
+        project_id: str,
+    ):
+        """
+        Launches a MLEngine job and wait for it to reach a terminal state.
+
+        :param project_id: The Google Cloud project id within which MLEngine
+            job will be launched. If set to None or missing, the default project_id from the Google Cloud
+            connection is used.
+        :param body: MLEngine Job object that should be provided to the MLEngine
+            API, such as: ::
+
+                {
+                  'jobId': 'my_job_id',
+                  'trainingInput': {
+                    'scaleTier': 'STANDARD_1',
+                    ...
+                  }
+                }
+        :return: The MLEngine job_id of the object if the job successfully reach a
+            terminal state (which might be FAILED or CANCELLED state).
+        """
+        hook = self.get_conn()
+
+        self._append_label(body)
+
+        request = hook.projects().jobs().create(parent=f"projects/{project_id}", body=body)
+        job_id = body["jobId"]
+        request.execute(num_retries=self.num_retries)
+        return job_id
+
     @GoogleBaseHook.fallback_to_default_project_id
     def cancel_job(
         self,
@@ -161,27 +208,26 @@ class MLEngineHook(GoogleBaseHook):
         :param job_id: A unique id for the want-to-be cancelled Google MLEngine training job.
 
         :return: Empty dict if cancelled successfully
-        :rtype: dict
         :raises: googleapiclient.errors.HttpError
         """
         hook = self.get_conn()
 
-        request = hook.projects().jobs().cancel(name=f'projects/{project_id}/jobs/{job_id}')
+        request = hook.projects().jobs().cancel(name=f"projects/{project_id}/jobs/{job_id}")
 
         try:
             return request.execute(num_retries=self.num_retries)
         except HttpError as e:
             if e.resp.status == 404:
-                self.log.error('Job with job_id %s does not exist. ', job_id)
+                self.log.error("Job with job_id %s does not exist. ", job_id)
                 raise
             elif e.resp.status == 400:
-                self.log.info('Job with job_id %s is already complete, cancellation aborted.', job_id)
+                self.log.info("Job with job_id %s is already complete, cancellation aborted.", job_id)
                 return {}
             else:
-                self.log.error('Failed to cancel MLEngine job: %s', e)
+                self.log.error("Failed to cancel MLEngine job: %s", e)
                 raise
 
-    def _get_job(self, project_id: str, job_id: str) -> dict:
+    def get_job(self, project_id: str, job_id: str) -> dict:
         """
         Gets a MLEngine job based on the job id.
 
@@ -189,11 +235,10 @@ class MLEngineHook(GoogleBaseHook):
             project_id from the Google Cloud connection is used. (templated)
         :param job_id: A unique id for the Google MLEngine job. (templated)
         :return: MLEngine job object if succeed.
-        :rtype: dict
         :raises: googleapiclient.errors.HttpError
         """
         hook = self.get_conn()
-        job_name = f'projects/{project_id}/jobs/{job_id}'
+        job_name = f"projects/{project_id}/jobs/{job_id}"
         request = hook.projects().jobs().get(name=job_name)
         while True:
             try:
@@ -203,7 +248,7 @@ class MLEngineHook(GoogleBaseHook):
                     # polling after 30 seconds when quota failure occurs
                     time.sleep(30)
                 else:
-                    self.log.error('Failed to get MLEngine job: %s', e)
+                    self.log.error("Failed to get MLEngine job: %s", e)
                     raise
 
     def _wait_for_job_done(self, project_id: str, job_id: str, interval: int = 30):
@@ -224,8 +269,8 @@ class MLEngineHook(GoogleBaseHook):
         if interval <= 0:
             raise ValueError("Interval must be > 0")
         while True:
-            job = self._get_job(project_id, job_id)
-            if job['state'] in ['SUCCEEDED', 'FAILED', 'CANCELLED']:
+            job = self.get_job(project_id, job_id)
+            if job["state"] in ["SUCCEEDED", "FAILED", "CANCELLED"]:
                 return job
             time.sleep(interval)
 
@@ -247,23 +292,22 @@ class MLEngineHook(GoogleBaseHook):
             (templated)
         :return: If the version was created successfully, returns the operation.
             Otherwise raises an error .
-        :rtype: dict
         """
         hook = self.get_conn()
-        parent_name = f'projects/{project_id}/models/{model_name}'
+        parent_name = f"projects/{project_id}/models/{model_name}"
 
         self._append_label(version_spec)
 
         create_request = hook.projects().models().versions().create(parent=parent_name, body=version_spec)
         response = create_request.execute(num_retries=self.num_retries)
-        get_request = hook.projects().operations().get(name=response['name'])
+        get_request = hook.projects().operations().get(name=response["name"])
 
         return _poll_with_exponential_delay(
             request=get_request,
             execute_num_retries=self.num_retries,
             max_n=9,
-            is_done_func=lambda resp: resp.get('done', False),
-            is_error_func=lambda resp: resp.get('error', None) is not None,
+            is_done_func=lambda resp: resp.get("done", False),
+            is_error_func=lambda resp: resp.get("error", None) is not None,
         )
 
     @GoogleBaseHook.fallback_to_default_project_id
@@ -283,20 +327,19 @@ class MLEngineHook(GoogleBaseHook):
             or missing, the default project_id from the Google Cloud connection is used. (templated)
         :return: If successful, return an instance of Version.
             Otherwise raises an error.
-        :rtype: dict
         :raises: googleapiclient.errors.HttpError
         """
         hook = self.get_conn()
-        full_version_name = f'projects/{project_id}/models/{model_name}/versions/{version_name}'
+        full_version_name = f"projects/{project_id}/models/{model_name}/versions/{version_name}"
 
         request = hook.projects().models().versions().setDefault(name=full_version_name, body={})
 
         try:
             response = request.execute(num_retries=self.num_retries)
-            self.log.info('Successfully set version: %s to default', response)
+            self.log.info("Successfully set version: %s to default", response)
             return response
         except HttpError as e:
-            self.log.error('Something went wrong: %s', e)
+            self.log.error("Something went wrong: %s", e)
             raise
 
     @GoogleBaseHook.fallback_to_default_project_id
@@ -313,18 +356,17 @@ class MLEngineHook(GoogleBaseHook):
         :param project_id: The Google Cloud project name to which MLEngine model belongs. If set to None or
             missing, the default project_id from the Google Cloud connection is used. (templated)
         :return: return an list of instance of Version.
-        :rtype: List[Dict]
         :raises: googleapiclient.errors.HttpError
         """
         hook = self.get_conn()
-        result = []  # type: List[Dict]
-        full_parent_name = f'projects/{project_id}/models/{model_name}'
+        result: list[dict] = []
+        full_parent_name = f"projects/{project_id}/models/{model_name}"
 
         request = hook.projects().models().versions().list(parent=full_parent_name, pageSize=100)
 
         while request is not None:
             response = request.execute(num_retries=self.num_retries)
-            result.extend(response.get('versions', []))
+            result.extend(response.get("versions", []))
 
             request = (
                 hook.projects()
@@ -351,20 +393,19 @@ class MLEngineHook(GoogleBaseHook):
             model belongs.
         :return: If the version was deleted successfully, returns the operation.
             Otherwise raises an error.
-        :rtype: Dict
         """
         hook = self.get_conn()
-        full_name = f'projects/{project_id}/models/{model_name}/versions/{version_name}'
+        full_name = f"projects/{project_id}/models/{model_name}/versions/{version_name}"
         delete_request = hook.projects().models().versions().delete(name=full_name)
         response = delete_request.execute(num_retries=self.num_retries)
-        get_request = hook.projects().operations().get(name=response['name'])
+        get_request = hook.projects().operations().get(name=response["name"])
 
         return _poll_with_exponential_delay(
             request=get_request,
             execute_num_retries=self.num_retries,
             max_n=9,
-            is_done_func=lambda resp: resp.get('done', False),
-            is_error_func=lambda resp: resp.get('error', None) is not None,
+            is_done_func=lambda resp: resp.get("done", False),
+            is_error_func=lambda resp: resp.get("error", None) is not None,
         )
 
     @GoogleBaseHook.fallback_to_default_project_id
@@ -381,13 +422,12 @@ class MLEngineHook(GoogleBaseHook):
             missing, the default project_id from the Google Cloud connection is used. (templated)
         :return: If the version was created successfully, returns the instance of Model.
             Otherwise raises an error.
-        :rtype: Dict
         :raises: googleapiclient.errors.HttpError
         """
         hook = self.get_conn()
-        if 'name' not in model or not model['name']:
+        if "name" not in model or not model["name"]:
             raise ValueError("Model name must be provided and could not be an empty string")
-        project = f'projects/{project_id}'
+        project = f"projects/{project_id}"
 
         self._append_label(model)
         try:
@@ -401,19 +441,19 @@ class MLEngineHook(GoogleBaseHook):
                 raise e
 
             error_detail = e.error_details[0]
-            if error_detail["@type"] != 'type.googleapis.com/google.rpc.BadRequest':
+            if error_detail["@type"] != "type.googleapis.com/google.rpc.BadRequest":
                 raise e
 
-            if "fieldViolations" not in error_detail or len(error_detail['fieldViolations']) != 1:
+            if "fieldViolations" not in error_detail or len(error_detail["fieldViolations"]) != 1:
                 raise e
 
-            field_violation = error_detail['fieldViolations'][0]
+            field_violation = error_detail["fieldViolations"][0]
             if (
                 field_violation["field"] != "model.name"
                 or field_violation["description"] != "A model with the same name already exists."
             ):
                 raise e
-            response = self.get_model(model_name=model['name'], project_id=project_id)
+            response = self.get_model(model_name=model["name"], project_id=project_id)
 
         return response
 
@@ -431,19 +471,18 @@ class MLEngineHook(GoogleBaseHook):
             or missing, the default project_id from the Google Cloud connection is used. (templated)
         :return: If the model exists, returns the instance of Model.
             Otherwise return None.
-        :rtype: Dict
         :raises: googleapiclient.errors.HttpError
         """
         hook = self.get_conn()
         if not model_name:
             raise ValueError("Model name must be provided and it could not be an empty string")
-        full_model_name = f'projects/{project_id}/models/{model_name}'
+        full_model_name = f"projects/{project_id}/models/{model_name}"
         request = hook.projects().models().get(name=full_model_name)
         try:
             return request.execute(num_retries=self.num_retries)
         except HttpError as e:
             if e.resp.status == 404:
-                self.log.error('Model was not found: %s', e)
+                self.log.error("Model was not found: %s", e)
                 return None
             raise
 
@@ -469,7 +508,7 @@ class MLEngineHook(GoogleBaseHook):
 
         if not model_name:
             raise ValueError("Model name must be provided and it could not be an empty string")
-        model_path = f'projects/{project_id}/models/{model_name}'
+        model_path = f"projects/{project_id}/models/{model_name}"
         if delete_contents:
             self._delete_all_versions(model_name, project_id)
         request = hook.projects().models().delete(name=model_path)
@@ -477,22 +516,89 @@ class MLEngineHook(GoogleBaseHook):
             request.execute(num_retries=self.num_retries)
         except HttpError as e:
             if e.resp.status == 404:
-                self.log.error('Model was not found: %s', e)
+                self.log.error("Model was not found: %s", e)
                 return
             raise
 
     def _delete_all_versions(self, model_name: str, project_id: str):
         versions = self.list_versions(project_id=project_id, model_name=model_name)
         # The default version can only be deleted when it is the last one in the model
-        non_default_versions = (version for version in versions if not version.get('isDefault', False))
+        non_default_versions = (version for version in versions if not version.get("isDefault", False))
         for version in non_default_versions:
-            _, _, version_name = version['name'].rpartition('/')
+            _, _, version_name = version["name"].rpartition("/")
             self.delete_version(project_id=project_id, model_name=model_name, version_name=version_name)
-        default_versions = (version for version in versions if version.get('isDefault', False))
+        default_versions = (version for version in versions if version.get("isDefault", False))
         for version in default_versions:
-            _, _, version_name = version['name'].rpartition('/')
+            _, _, version_name = version["name"].rpartition("/")
             self.delete_version(project_id=project_id, model_name=model_name, version_name=version_name)
 
     def _append_label(self, model: dict) -> None:
-        model['labels'] = model.get('labels', {})
-        model['labels']['airflow-version'] = _AIRFLOW_VERSION
+        model["labels"] = model.get("labels", {})
+        model["labels"]["airflow-version"] = _AIRFLOW_VERSION
+
+
+class MLEngineAsyncHook(GoogleBaseAsyncHook):
+    """Uses gcloud-aio library to retrieve Job details"""
+
+    sync_hook_class = MLEngineHook
+
+    def _check_fileds(
+        self,
+        job_id: str,
+        project_id: str | None = None,
+    ):
+        if not project_id:
+            raise AirflowException("Google Cloud project id is required.")
+        if not job_id:
+            raise AirflowException("An unique job id is required for Google MLEngine training job.")
+
+    async def _get_link(self, url: str, session: Session):
+        s = AioSession(session)
+        t = Token(scopes=["https://www.googleapis.com/auth/cloud-platform"])
+        headers = {
+            "Authorization": f"Bearer {t.get()}",
+            "accept": "application/json",
+            "accept-encoding": "gzip, deflate",
+            "user-agent": "(gzip)",
+            "x-goog-api-client": "gdcl/1.12.11 gl-python/3.8.15",
+        }
+        return await s.get(url=url, headers=headers)
+
+    async def get_job(self, job_id: str, session: Session, project_id: str | None = None):
+        """Get the specified job resource by job ID and project ID."""
+        self._check_fileds(project_id=project_id, job_id=job_id)
+
+        url = f"https://ml.googleapis.com/v1/projects/{project_id}/jobs/{job_id}"
+        return await self._get_link(url=url, session=session)
+
+    async def get_job_status(
+        self,
+        job_id: str,
+        project_id: str | None = None,
+    ) -> str | None:
+        """
+        Polls for job status asynchronously using gcloud-aio.
+
+        Note that an OSError is raised when Job results are still pending.
+        Exception means that Job finished with errors
+        """
+        self._check_fileds(project_id=project_id, job_id=job_id)
+
+        async with ClientSession() as s:
+            try:
+                job_response = await self.get_job(
+                    project_id=project_id, job_id=job_id, session=cast(Session, s)
+                )
+                json_response = await job_response.json()
+                self.log.info("Retrieving json_response: %s", json_response)
+
+                if json_response["state"] in ["SUCCEEDED", "FAILED", "CANCELLED"]:
+                    job_status = "success"
+                elif json_response["state"] in ["PREPARING", "RUNNING"]:
+                    job_status = "pending"
+            except OSError:
+                job_status = "pending"
+            except Exception as e:
+                self.log.info("Query execution finished with errors...")
+                job_status = str(e)
+            return job_status
