@@ -16,8 +16,11 @@
 # specific language governing permissions and limitations
 # under the License.
 """This module contains a Google Cloud Text to Speech Hook."""
-from typing import Dict, Optional, Sequence, Union
+from __future__ import annotations
 
+from typing import Sequence
+
+from google.api_core.gapic_v1.method import DEFAULT, _MethodDefault
 from google.api_core.retry import Retry
 from google.cloud.texttospeech_v1 import TextToSpeechClient
 from google.cloud.texttospeech_v1.types import (
@@ -39,9 +42,6 @@ class CloudTextToSpeechHook(GoogleBaseHook):
     keyword arguments rather than positional.
 
     :param gcp_conn_id: The connection ID to use when fetching connection info.
-    :param delegate_to: The account to impersonate using domain-wide delegation of authority,
-        if any. For this to work, the service account making the request must have
-        domain-wide delegation enabled.
     :param impersonation_chain: Optional service account to impersonate using short-term
         credentials, or chained list of accounts required to get the access_token
         of the last account in the list, which will be impersonated in the request.
@@ -55,37 +55,40 @@ class CloudTextToSpeechHook(GoogleBaseHook):
     def __init__(
         self,
         gcp_conn_id: str = "google_cloud_default",
-        delegate_to: Optional[str] = None,
-        impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
+        impersonation_chain: str | Sequence[str] | None = None,
+        **kwargs,
     ) -> None:
+        if kwargs.get("delegate_to") is not None:
+            raise RuntimeError(
+                "The `delegate_to` parameter has been deprecated before and finally removed in this version"
+                " of Google Provider. You MUST convert it to `impersonate_chain`"
+            )
         super().__init__(
             gcp_conn_id=gcp_conn_id,
-            delegate_to=delegate_to,
             impersonation_chain=impersonation_chain,
         )
-        self._client = None  # type: Optional[TextToSpeechClient]
+        self._client: TextToSpeechClient | None = None
 
     def get_conn(self) -> TextToSpeechClient:
         """
         Retrieves connection to Cloud Text to Speech.
 
         :return: Google Cloud Text to Speech client object.
-        :rtype: google.cloud.texttospeech_v1.TextToSpeechClient
         """
         if not self._client:
 
-            self._client = TextToSpeechClient(credentials=self._get_credentials(), client_info=CLIENT_INFO)
+            self._client = TextToSpeechClient(credentials=self.get_credentials(), client_info=CLIENT_INFO)
 
         return self._client
 
     @GoogleBaseHook.quota_retry()
     def synthesize_speech(
         self,
-        input_data: Union[Dict, SynthesisInput],
-        voice: Union[Dict, VoiceSelectionParams],
-        audio_config: Union[Dict, AudioConfig],
-        retry: Optional[Retry] = None,
-        timeout: Optional[float] = None,
+        input_data: dict | SynthesisInput,
+        voice: dict | VoiceSelectionParams,
+        audio_config: dict | AudioConfig,
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
     ) -> SynthesizeSpeechResponse:
         """
         Synthesizes text input
@@ -102,7 +105,6 @@ class CloudTextToSpeechHook(GoogleBaseHook):
             Note that if retry is specified, the timeout applies to each individual attempt.
         :return: SynthesizeSpeechResponse See more:
             https://googleapis.github.io/google-cloud-python/latest/texttospeech/gapic/v1/types.html#google.cloud.texttospeech_v1.types.SynthesizeSpeechResponse
-        :rtype: object
         """
         client = self.get_conn()
         self.log.info("Synthesizing input: %s", input_data)
