@@ -17,7 +17,6 @@
 # under the License.
 from __future__ import annotations
 
-import warnings
 from typing import TYPE_CHECKING, Sequence
 
 from google.api_core.exceptions import AlreadyExists
@@ -28,9 +27,9 @@ from google.cloud.orchestration.airflow.service_v1.types import Environment
 from google.protobuf.field_mask_pb2 import FieldMask
 
 from airflow import AirflowException
-from airflow.models import BaseOperator
 from airflow.providers.google.cloud.hooks.cloud_composer import CloudComposerHook
 from airflow.providers.google.cloud.links.base import BaseGoogleLink
+from airflow.providers.google.cloud.operators.cloud_base import GoogleCloudBaseOperator
 from airflow.providers.google.cloud.triggers.cloud_composer import CloudComposerExecutionTrigger
 from airflow.providers.google.common.consts import GOOGLE_DEFAULT_DEFERRABLE_METHOD_NAME
 
@@ -89,7 +88,7 @@ class CloudComposerEnvironmentsLink(BaseGoogleLink):
         )
 
 
-class CloudComposerCreateEnvironmentOperator(BaseOperator):
+class CloudComposerCreateEnvironmentOperator(GoogleCloudBaseOperator):
     """
     Create a new environment.
 
@@ -106,9 +105,6 @@ class CloudComposerCreateEnvironmentOperator(BaseOperator):
         If set as a sequence, the identities from the list must grant
         Service Account Token Creator IAM role to the directly preceding identity, with first
         account from the list granting this role to the originating account (templated).
-    :param delegate_to: The account to impersonate using domain-wide delegation of authority,
-        if any. For this to work, the service account making the request must have
-        domain-wide delegation enabled.
     :param retry: Designation of what errors, if any, should be retried.
     :param timeout: The timeout for this request.
     :param metadata: Strings which should be sent along with the request as metadata.
@@ -136,7 +132,6 @@ class CloudComposerCreateEnvironmentOperator(BaseOperator):
         environment: Environment | dict,
         gcp_conn_id: str = "google_cloud_default",
         impersonation_chain: str | Sequence[str] | None = None,
-        delegate_to: str | None = None,
         retry: Retry | _MethodDefault = DEFAULT,
         timeout: float | None = None,
         metadata: Sequence[tuple[str, str]] = (),
@@ -154,11 +149,6 @@ class CloudComposerCreateEnvironmentOperator(BaseOperator):
         self.metadata = metadata
         self.gcp_conn_id = gcp_conn_id
         self.impersonation_chain = impersonation_chain
-        if delegate_to:
-            warnings.warn(
-                "'delegate_to' parameter is deprecated, please use 'impersonation_chain'", DeprecationWarning
-            )
-        self.delegate_to = delegate_to
         self.deferrable = deferrable
         self.pooling_period_seconds = pooling_period_seconds
 
@@ -166,7 +156,6 @@ class CloudComposerCreateEnvironmentOperator(BaseOperator):
         hook = CloudComposerHook(
             gcp_conn_id=self.gcp_conn_id,
             impersonation_chain=self.impersonation_chain,
-            delegate_to=self.delegate_to,
         )
 
         name = hook.get_environment_name(self.project_id, self.region, self.environment_id)
@@ -198,7 +187,6 @@ class CloudComposerCreateEnvironmentOperator(BaseOperator):
                         operation_name=result.operation.name,
                         gcp_conn_id=self.gcp_conn_id,
                         impersonation_chain=self.impersonation_chain,
-                        delegate_to=self.delegate_to,
                         pooling_period_seconds=self.pooling_period_seconds,
                     ),
                     method_name=GOOGLE_DEFAULT_DEFERRABLE_METHOD_NAME,
@@ -219,7 +207,6 @@ class CloudComposerCreateEnvironmentOperator(BaseOperator):
             hook = CloudComposerHook(
                 gcp_conn_id=self.gcp_conn_id,
                 impersonation_chain=self.impersonation_chain,
-                delegate_to=self.delegate_to,
             )
 
             env = hook.get_environment(
@@ -235,7 +222,7 @@ class CloudComposerCreateEnvironmentOperator(BaseOperator):
             raise AirflowException(f"Unexpected error in the operation: {event['operation_name']}")
 
 
-class CloudComposerDeleteEnvironmentOperator(BaseOperator):
+class CloudComposerDeleteEnvironmentOperator(GoogleCloudBaseOperator):
     """
     Delete an environment.
 
@@ -254,12 +241,9 @@ class CloudComposerDeleteEnvironmentOperator(BaseOperator):
         If set as a sequence, the identities from the list must grant
         Service Account Token Creator IAM role to the directly preceding identity, with first
         account from the list granting this role to the originating account (templated).
-    :param delegate_to: The account to impersonate using domain-wide delegation of authority,
-        if any. For this to work, the service account making the request must have
-        domain-wide delegation enabled.
     :param deferrable: Run operator in the deferrable mode
     :param pooling_period_seconds: Optional: Control the rate of the poll for the result of deferrable run.
-        By default the trigger will poll every 30 seconds.
+        By default, the trigger will poll every 30 seconds.
     """
 
     template_fields = (
@@ -280,7 +264,6 @@ class CloudComposerDeleteEnvironmentOperator(BaseOperator):
         metadata: Sequence[tuple[str, str]] = (),
         gcp_conn_id: str = "google_cloud_default",
         impersonation_chain: str | Sequence[str] | None = None,
-        delegate_to: str | None = None,
         deferrable: bool = False,
         pooling_period_seconds: int = 30,
         **kwargs,
@@ -294,11 +277,6 @@ class CloudComposerDeleteEnvironmentOperator(BaseOperator):
         self.metadata = metadata
         self.gcp_conn_id = gcp_conn_id
         self.impersonation_chain = impersonation_chain
-        if delegate_to:
-            warnings.warn(
-                "'delegate_to' parameter is deprecated, please use 'impersonation_chain'", DeprecationWarning
-            )
-        self.delegate_to = delegate_to
         self.deferrable = deferrable
         self.pooling_period_seconds = pooling_period_seconds
 
@@ -306,7 +284,6 @@ class CloudComposerDeleteEnvironmentOperator(BaseOperator):
         hook = CloudComposerHook(
             gcp_conn_id=self.gcp_conn_id,
             impersonation_chain=self.impersonation_chain,
-            delegate_to=self.delegate_to,
         )
         result = hook.delete_environment(
             project_id=self.project_id,
@@ -326,7 +303,6 @@ class CloudComposerDeleteEnvironmentOperator(BaseOperator):
                     operation_name=result.operation.name,
                     gcp_conn_id=self.gcp_conn_id,
                     impersonation_chain=self.impersonation_chain,
-                    delegate_to=self.delegate_to,
                     pooling_period_seconds=self.pooling_period_seconds,
                 ),
                 method_name=GOOGLE_DEFAULT_DEFERRABLE_METHOD_NAME,
@@ -336,7 +312,7 @@ class CloudComposerDeleteEnvironmentOperator(BaseOperator):
         pass
 
 
-class CloudComposerGetEnvironmentOperator(BaseOperator):
+class CloudComposerGetEnvironmentOperator(GoogleCloudBaseOperator):
     """
     Get an existing environment.
 
@@ -355,9 +331,6 @@ class CloudComposerGetEnvironmentOperator(BaseOperator):
         If set as a sequence, the identities from the list must grant
         Service Account Token Creator IAM role to the directly preceding identity, with first
         account from the list granting this role to the originating account (templated).
-    :param delegate_to: The account to impersonate using domain-wide delegation of authority,
-        if any. For this to work, the service account making the request must have
-        domain-wide delegation enabled.
     """
 
     template_fields = (
@@ -380,7 +353,6 @@ class CloudComposerGetEnvironmentOperator(BaseOperator):
         metadata: Sequence[tuple[str, str]] = (),
         gcp_conn_id: str = "google_cloud_default",
         impersonation_chain: str | Sequence[str] | None = None,
-        delegate_to: str | None = None,
         **kwargs,
     ) -> None:
         super().__init__(**kwargs)
@@ -392,17 +364,11 @@ class CloudComposerGetEnvironmentOperator(BaseOperator):
         self.metadata = metadata
         self.gcp_conn_id = gcp_conn_id
         self.impersonation_chain = impersonation_chain
-        if delegate_to:
-            warnings.warn(
-                "'delegate_to' parameter is deprecated, please use 'impersonation_chain'", DeprecationWarning
-            )
-        self.delegate_to = delegate_to
 
     def execute(self, context: Context):
         hook = CloudComposerHook(
             gcp_conn_id=self.gcp_conn_id,
             impersonation_chain=self.impersonation_chain,
-            delegate_to=self.delegate_to,
         )
 
         result = hook.get_environment(
@@ -418,7 +384,7 @@ class CloudComposerGetEnvironmentOperator(BaseOperator):
         return Environment.to_dict(result)
 
 
-class CloudComposerListEnvironmentsOperator(BaseOperator):
+class CloudComposerListEnvironmentsOperator(GoogleCloudBaseOperator):
     """
     List environments.
 
@@ -439,9 +405,6 @@ class CloudComposerListEnvironmentsOperator(BaseOperator):
         If set as a sequence, the identities from the list must grant
         Service Account Token Creator IAM role to the directly preceding identity, with first
         account from the list granting this role to the originating account (templated).
-    :param delegate_to: The account to impersonate using domain-wide delegation of authority,
-        if any. For this to work, the service account making the request must have
-        domain-wide delegation enabled.
     """
 
     template_fields = (
@@ -464,7 +427,6 @@ class CloudComposerListEnvironmentsOperator(BaseOperator):
         metadata: Sequence[tuple[str, str]] = (),
         gcp_conn_id: str = "google_cloud_default",
         impersonation_chain: str | Sequence[str] | None = None,
-        delegate_to: str | None = None,
         **kwargs,
     ) -> None:
         super().__init__(**kwargs)
@@ -477,17 +439,11 @@ class CloudComposerListEnvironmentsOperator(BaseOperator):
         self.metadata = metadata
         self.gcp_conn_id = gcp_conn_id
         self.impersonation_chain = impersonation_chain
-        if delegate_to:
-            warnings.warn(
-                "'delegate_to' parameter is deprecated, please use 'impersonation_chain'", DeprecationWarning
-            )
-        self.delegate_to = delegate_to
 
     def execute(self, context: Context):
         hook = CloudComposerHook(
             gcp_conn_id=self.gcp_conn_id,
             impersonation_chain=self.impersonation_chain,
-            delegate_to=self.delegate_to,
         )
         CloudComposerEnvironmentsLink.persist(operator_instance=self, context=context)
         result = hook.list_environments(
@@ -502,7 +458,7 @@ class CloudComposerListEnvironmentsOperator(BaseOperator):
         return [Environment.to_dict(env) for env in result]
 
 
-class CloudComposerUpdateEnvironmentOperator(BaseOperator):
+class CloudComposerUpdateEnvironmentOperator(GoogleCloudBaseOperator):
     r"""
     Update an environment.
 
@@ -526,12 +482,9 @@ class CloudComposerUpdateEnvironmentOperator(BaseOperator):
         If set as a sequence, the identities from the list must grant
         Service Account Token Creator IAM role to the directly preceding identity, with first
         account from the list granting this role to the originating account (templated).
-    :param delegate_to: The account to impersonate using domain-wide delegation of authority,
-        if any. For this to work, the service account making the request must have
-        domain-wide delegation enabled.
     :param deferrable: Run operator in the deferrable mode
     :param pooling_period_seconds: Optional: Control the rate of the poll for the result of deferrable run.
-        By default the trigger will poll every 30 seconds.
+        By default, the trigger will poll every 30 seconds.
     """
 
     template_fields = (
@@ -556,7 +509,6 @@ class CloudComposerUpdateEnvironmentOperator(BaseOperator):
         metadata: Sequence[tuple[str, str]] = (),
         gcp_conn_id: str = "google_cloud_default",
         impersonation_chain: str | Sequence[str] | None = None,
-        delegate_to: str | None = None,
         deferrable: bool = False,
         pooling_period_seconds: int = 30,
         **kwargs,
@@ -572,11 +524,6 @@ class CloudComposerUpdateEnvironmentOperator(BaseOperator):
         self.metadata = metadata
         self.gcp_conn_id = gcp_conn_id
         self.impersonation_chain = impersonation_chain
-        if delegate_to:
-            warnings.warn(
-                "'delegate_to' parameter is deprecated, please use 'impersonation_chain'", DeprecationWarning
-            )
-        self.delegate_to = delegate_to
         self.deferrable = deferrable
         self.pooling_period_seconds = pooling_period_seconds
 
@@ -584,7 +531,6 @@ class CloudComposerUpdateEnvironmentOperator(BaseOperator):
         hook = CloudComposerHook(
             gcp_conn_id=self.gcp_conn_id,
             impersonation_chain=self.impersonation_chain,
-            delegate_to=self.delegate_to,
         )
 
         result = hook.update_environment(
@@ -610,7 +556,6 @@ class CloudComposerUpdateEnvironmentOperator(BaseOperator):
                     operation_name=result.operation.name,
                     gcp_conn_id=self.gcp_conn_id,
                     impersonation_chain=self.impersonation_chain,
-                    delegate_to=self.delegate_to,
                     pooling_period_seconds=self.pooling_period_seconds,
                 ),
                 method_name=GOOGLE_DEFAULT_DEFERRABLE_METHOD_NAME,
@@ -621,7 +566,6 @@ class CloudComposerUpdateEnvironmentOperator(BaseOperator):
             hook = CloudComposerHook(
                 gcp_conn_id=self.gcp_conn_id,
                 impersonation_chain=self.impersonation_chain,
-                delegate_to=self.delegate_to,
             )
 
             env = hook.get_environment(
@@ -637,7 +581,7 @@ class CloudComposerUpdateEnvironmentOperator(BaseOperator):
             raise AirflowException(f"Unexpected error in the operation: {event['operation_name']}")
 
 
-class CloudComposerListImageVersionsOperator(BaseOperator):
+class CloudComposerListImageVersionsOperator(GoogleCloudBaseOperator):
     """
     List ImageVersions for provided location.
 
@@ -654,9 +598,6 @@ class CloudComposerListImageVersionsOperator(BaseOperator):
         If set as a sequence, the identities from the list must grant
         Service Account Token Creator IAM role to the directly preceding identity, with first
         account from the list granting this role to the originating account (templated).
-    :param delegate_to: The account to impersonate using domain-wide delegation of authority,
-        if any. For this to work, the service account making the request must have
-        domain-wide delegation enabled.
     """
 
     template_fields = (
@@ -678,7 +619,6 @@ class CloudComposerListImageVersionsOperator(BaseOperator):
         metadata: Sequence[tuple[str, str]] = (),
         gcp_conn_id: str = "google_cloud_default",
         impersonation_chain: str | Sequence[str] | None = None,
-        delegate_to: str | None = None,
         **kwargs,
     ) -> None:
         super().__init__(**kwargs)
@@ -692,17 +632,11 @@ class CloudComposerListImageVersionsOperator(BaseOperator):
         self.metadata = metadata
         self.gcp_conn_id = gcp_conn_id
         self.impersonation_chain = impersonation_chain
-        if delegate_to:
-            warnings.warn(
-                "'delegate_to' parameter is deprecated, please use 'impersonation_chain'", DeprecationWarning
-            )
-        self.delegate_to = delegate_to
 
     def execute(self, context: Context):
         hook = CloudComposerHook(
             gcp_conn_id=self.gcp_conn_id,
             impersonation_chain=self.impersonation_chain,
-            delegate_to=self.delegate_to,
         )
         result = hook.list_image_versions(
             project_id=self.project_id,
