@@ -18,13 +18,11 @@
 """This module contains Google Cloud Transfer operators."""
 from __future__ import annotations
 
-import warnings
 from copy import deepcopy
 from datetime import date, time
 from typing import TYPE_CHECKING, Sequence
 
 from airflow.exceptions import AirflowException
-from airflow.models import BaseOperator
 from airflow.providers.amazon.aws.hooks.base_aws import AwsBaseHook
 from airflow.providers.google.cloud.hooks.cloud_storage_transfer_service import (
     ACCESS_KEY_ID,
@@ -61,6 +59,7 @@ from airflow.providers.google.cloud.links.cloud_storage_transfer import (
     CloudStorageTransferJobLink,
     CloudStorageTransferListLink,
 )
+from airflow.providers.google.cloud.operators.cloud_base import GoogleCloudBaseOperator
 from airflow.providers.google.cloud.utils.helpers import normalize_directory_path
 
 if TYPE_CHECKING:
@@ -174,7 +173,7 @@ class TransferJobValidator:
             self._verify_data_source()
 
 
-class CloudDataTransferServiceCreateJobOperator(BaseOperator):
+class CloudDataTransferServiceCreateJobOperator(GoogleCloudBaseOperator):
     """
     Creates a transfer job that runs periodically.
 
@@ -269,7 +268,7 @@ class CloudDataTransferServiceCreateJobOperator(BaseOperator):
         return result
 
 
-class CloudDataTransferServiceUpdateJobOperator(BaseOperator):
+class CloudDataTransferServiceUpdateJobOperator(GoogleCloudBaseOperator):
     """
     Updates a transfer job that runs periodically.
 
@@ -359,7 +358,7 @@ class CloudDataTransferServiceUpdateJobOperator(BaseOperator):
         return hook.update_transfer_job(job_name=self.job_name, body=self.body)
 
 
-class CloudDataTransferServiceDeleteJobOperator(BaseOperator):
+class CloudDataTransferServiceDeleteJobOperator(GoogleCloudBaseOperator):
     """
     Delete a transfer job. This is a soft delete. After a transfer job is
     deleted, the job and all the transfer executions are subject to garbage
@@ -428,7 +427,7 @@ class CloudDataTransferServiceDeleteJobOperator(BaseOperator):
         hook.delete_transfer_job(job_name=self.job_name, project_id=self.project_id)
 
 
-class CloudDataTransferServiceGetOperationOperator(BaseOperator):
+class CloudDataTransferServiceGetOperationOperator(GoogleCloudBaseOperator):
     """
     Gets the latest state of a long-running operation in Google Storage Transfer
     Service.
@@ -502,7 +501,7 @@ class CloudDataTransferServiceGetOperationOperator(BaseOperator):
         return operation
 
 
-class CloudDataTransferServiceListOperationsOperator(BaseOperator):
+class CloudDataTransferServiceListOperationsOperator(GoogleCloudBaseOperator):
     """
     Lists long-running operations in Google Storage Transfer
     Service that match the specified filter.
@@ -585,7 +584,7 @@ class CloudDataTransferServiceListOperationsOperator(BaseOperator):
         return operations_list
 
 
-class CloudDataTransferServicePauseOperationOperator(BaseOperator):
+class CloudDataTransferServicePauseOperationOperator(GoogleCloudBaseOperator):
     """
     Pauses a transfer operation in Google Storage Transfer Service.
 
@@ -644,7 +643,7 @@ class CloudDataTransferServicePauseOperationOperator(BaseOperator):
         hook.pause_transfer_operation(operation_name=self.operation_name)
 
 
-class CloudDataTransferServiceResumeOperationOperator(BaseOperator):
+class CloudDataTransferServiceResumeOperationOperator(GoogleCloudBaseOperator):
     """
     Resumes a transfer operation in Google Storage Transfer Service.
 
@@ -703,7 +702,7 @@ class CloudDataTransferServiceResumeOperationOperator(BaseOperator):
         hook.resume_transfer_operation(operation_name=self.operation_name)
 
 
-class CloudDataTransferServiceCancelOperationOperator(BaseOperator):
+class CloudDataTransferServiceCancelOperationOperator(GoogleCloudBaseOperator):
     """
     Cancels a transfer operation in Google Storage Transfer Service.
 
@@ -763,7 +762,7 @@ class CloudDataTransferServiceCancelOperationOperator(BaseOperator):
         hook.cancel_transfer_operation(operation_name=self.operation_name)
 
 
-class CloudDataTransferServiceS3ToGCSOperator(BaseOperator):
+class CloudDataTransferServiceS3ToGCSOperator(GoogleCloudBaseOperator):
     """
     Synchronizes an S3 bucket with a Google Cloud Storage bucket using the
     Google Cloud Storage Transfer Service.
@@ -795,9 +794,6 @@ class CloudDataTransferServiceS3ToGCSOperator(BaseOperator):
     :param aws_conn_id: The source S3 connection
     :param gcp_conn_id: The destination connection ID to use
         when connecting to Google Cloud Storage.
-    :param delegate_to: Google account to impersonate using domain-wide delegation of authority,
-        if any. For this to work, the service account making the request must have
-        domain-wide delegation enabled.
     :param description: Optional transfer service job description
     :param schedule: Optional transfer service schedule;
         If not set, run transfer job once as soon as the operator runs
@@ -849,7 +845,6 @@ class CloudDataTransferServiceS3ToGCSOperator(BaseOperator):
         project_id: str | None = None,
         aws_conn_id: str = "aws_default",
         gcp_conn_id: str = "google_cloud_default",
-        delegate_to: str | None = None,
         description: str | None = None,
         schedule: dict | None = None,
         object_conditions: dict | None = None,
@@ -869,11 +864,6 @@ class CloudDataTransferServiceS3ToGCSOperator(BaseOperator):
         self.project_id = project_id
         self.aws_conn_id = aws_conn_id
         self.gcp_conn_id = gcp_conn_id
-        if delegate_to:
-            warnings.warn(
-                "'delegate_to' parameter is deprecated, please use 'impersonation_chain'", DeprecationWarning
-            )
-        self.delegate_to = delegate_to
         self.description = description
         self.schedule = schedule
         self.object_conditions = object_conditions
@@ -891,7 +881,6 @@ class CloudDataTransferServiceS3ToGCSOperator(BaseOperator):
     def execute(self, context: Context) -> None:
         hook = CloudDataTransferServiceHook(
             gcp_conn_id=self.gcp_conn_id,
-            delegate_to=self.delegate_to,
             impersonation_chain=self.google_impersonation_chain,
         )
         body = self._create_body()
@@ -936,7 +925,7 @@ class CloudDataTransferServiceS3ToGCSOperator(BaseOperator):
         return body
 
 
-class CloudDataTransferServiceGCSToGCSOperator(BaseOperator):
+class CloudDataTransferServiceGCSToGCSOperator(GoogleCloudBaseOperator):
     """
     Copies objects from a bucket to another using the Google Cloud Storage Transfer Service.
 
@@ -971,9 +960,6 @@ class CloudDataTransferServiceGCSToGCSOperator(BaseOperator):
         owns the job
     :param gcp_conn_id: Optional connection ID to use when connecting to Google Cloud
         Storage.
-    :param delegate_to: Google account to impersonate using domain-wide delegation of authority,
-        if any. For this to work, the service account making the request must have
-        domain-wide delegation enabled.
     :param description: Optional transfer service job description
     :param schedule: Optional transfer service schedule;
         If not set, run transfer job once as soon as the operator runs
@@ -1024,7 +1010,6 @@ class CloudDataTransferServiceGCSToGCSOperator(BaseOperator):
         destination_path: str | None = None,
         project_id: str | None = None,
         gcp_conn_id: str = "google_cloud_default",
-        delegate_to: str | None = None,
         description: str | None = None,
         schedule: dict | None = None,
         object_conditions: dict | None = None,
@@ -1043,11 +1028,6 @@ class CloudDataTransferServiceGCSToGCSOperator(BaseOperator):
         self.destination_path = destination_path
         self.project_id = project_id
         self.gcp_conn_id = gcp_conn_id
-        if delegate_to:
-            warnings.warn(
-                "'delegate_to' parameter is deprecated, please use 'impersonation_chain'", DeprecationWarning
-            )
-        self.delegate_to = delegate_to
         self.description = description
         self.schedule = schedule
         self.object_conditions = object_conditions
@@ -1065,7 +1045,6 @@ class CloudDataTransferServiceGCSToGCSOperator(BaseOperator):
     def execute(self, context: Context) -> None:
         hook = CloudDataTransferServiceHook(
             gcp_conn_id=self.gcp_conn_id,
-            delegate_to=self.delegate_to,
             impersonation_chain=self.google_impersonation_chain,
         )
 
