@@ -20,7 +20,7 @@ from __future__ import annotations
 
 from typing import TYPE_CHECKING, Iterable, Sequence
 
-from airflow.exceptions import AirflowException
+from airflow.exceptions import AirflowException, AirflowNotFoundException
 from airflow.providers.google.cloud.hooks.datafusion import DataFusionHook
 from airflow.sensors.base import BaseSensorOperator
 
@@ -43,9 +43,6 @@ class CloudDataFusionPipelineStateSensor(BaseSensorOperator):
         is always default. If your pipeline belongs to an Enterprise edition instance, you
         can create a namespace.
     :param gcp_conn_id: The connection ID to use when fetching connection info.
-    :param delegate_to: The account to impersonate using domain-wide delegation of authority,
-        if any. For this to work, the service account making the request must have
-        domain-wide delegation enabled.
     :param impersonation_chain: Optional service account to impersonate using short-term
         credentials, or chained list of accounts required to get the access_token
         of the last account in the list, which will be impersonated in the request.
@@ -57,7 +54,7 @@ class CloudDataFusionPipelineStateSensor(BaseSensorOperator):
 
     """
 
-    template_fields: Sequence[str] = ('pipeline_id',)
+    template_fields: Sequence[str] = ("pipeline_id",)
 
     def __init__(
         self,
@@ -69,8 +66,7 @@ class CloudDataFusionPipelineStateSensor(BaseSensorOperator):
         failure_statuses: Iterable[str] | None = None,
         project_id: str | None = None,
         namespace: str = "default",
-        gcp_conn_id: str = 'google_cloud_default',
-        delegate_to: str | None = None,
+        gcp_conn_id: str = "google_cloud_default",
         impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
     ) -> None:
@@ -84,7 +80,6 @@ class CloudDataFusionPipelineStateSensor(BaseSensorOperator):
         self.project_id = project_id
         self.namespace = namespace
         self.gcp_conn_id = gcp_conn_id
-        self.delegate_to = delegate_to
         self.impersonation_chain = impersonation_chain
 
     def poke(self, context: Context) -> bool:
@@ -95,7 +90,6 @@ class CloudDataFusionPipelineStateSensor(BaseSensorOperator):
         )
         hook = DataFusionHook(
             gcp_conn_id=self.gcp_conn_id,
-            delegate_to=self.delegate_to,
             impersonation_chain=self.impersonation_chain,
         )
 
@@ -114,6 +108,8 @@ class CloudDataFusionPipelineStateSensor(BaseSensorOperator):
                 namespace=self.namespace,
             )
             pipeline_status = pipeline_workflow["status"]
+        except AirflowNotFoundException:
+            raise AirflowException("Specified Pipeline ID was not found.")
         except AirflowException:
             pass  # Because the pipeline may not be visible in system yet
         if pipeline_status is not None:
