@@ -17,7 +17,6 @@
 from __future__ import annotations
 
 import asyncio
-import warnings
 from typing import Any, AsyncIterator, Sequence
 
 from google.cloud.devtools.cloudbuild_v1.types import Build
@@ -41,10 +40,8 @@ class CloudBuildCreateBuildTrigger(BaseTrigger):
         If set as a sequence, the identities from the list must grant
         Service Account Token Creator IAM role to the directly preceding identity, with first
         account from the list granting this role to the originating account (templated).
-    :param delegate_to: The account to impersonate using domain-wide delegation of authority,
-        if any. For this to work, the service account making the request must have
-        domain-wide delegation enabled.
     :param poll_interval: polling period in seconds to check for the status
+    :param location: The location of the project.
     """
 
     def __init__(
@@ -53,20 +50,16 @@ class CloudBuildCreateBuildTrigger(BaseTrigger):
         project_id: str | None,
         gcp_conn_id: str = "google_cloud_default",
         impersonation_chain: str | Sequence[str] | None = None,
-        delegate_to: str | None = None,
         poll_interval: float = 4.0,
+        location: str = "global",
     ):
         super().__init__()
         self.id_ = id_
         self.project_id = project_id
         self.gcp_conn_id = gcp_conn_id
         self.impersonation_chain = impersonation_chain
-        if delegate_to:
-            warnings.warn(
-                "'delegate_to' parameter is deprecated, please use 'impersonation_chain'", DeprecationWarning
-            )
-        self.delegate_to = delegate_to
         self.poll_interval = poll_interval
+        self.location = location
 
     def serialize(self) -> tuple[str, dict[str, Any]]:
         """Serializes CloudBuildCreateBuildTrigger arguments and classpath."""
@@ -77,8 +70,8 @@ class CloudBuildCreateBuildTrigger(BaseTrigger):
                 "project_id": self.project_id,
                 "gcp_conn_id": self.gcp_conn_id,
                 "impersonation_chain": self.impersonation_chain,
-                "delegate_to": self.delegate_to,
                 "poll_interval": self.poll_interval,
+                "location": self.location,
             },
         )
 
@@ -91,6 +84,7 @@ class CloudBuildCreateBuildTrigger(BaseTrigger):
                 cloud_build_instance = await hook.get_cloud_build(
                     id_=self.id_,
                     project_id=self.project_id,
+                    location=self.location,
                 )
                 if cloud_build_instance._pb.status in (Build.Status.SUCCESS,):
                     yield TriggerEvent(
