@@ -16,8 +16,10 @@
 # specific language governing permissions and limitations
 # under the License.
 """This module contains a Google Cloud Storage to Google Drive transfer operator."""
+from __future__ import annotations
+
 import tempfile
-from typing import TYPE_CHECKING, Optional, Sequence, Union
+from typing import TYPE_CHECKING, Sequence
 
 from airflow.exceptions import AirflowException
 from airflow.models import BaseOperator
@@ -47,13 +49,11 @@ class GCSToGoogleDriveOperator(BaseOperator):
         :ref:`howto/operator:GCSToGoogleDriveOperator`
 
     :param source_bucket: The source Google Cloud Storage bucket where the object is. (templated)
-    :type source_bucket: str
     :param source_object: The source name of the object to copy in the Google cloud
         storage bucket. (templated)
         You can use only one wildcard for objects (filenames) within your bucket. The wildcard can appear
         inside the object name or at the end of the object name. Appending a wildcard to the bucket name
         is unsupported.
-    :type source_object: str
     :param destination_object: The destination name of the object in the destination Google Drive
         service. (templated)
         If a wildcard is supplied in the source_object argument, this is the prefix that will be prepended
@@ -63,16 +63,12 @@ class GCSToGoogleDriveOperator(BaseOperator):
         For example, with prefix ``foo/*`` and destination_object ``blah/``, the file ``foo/baz`` will be
         copied to ``blah/baz``; to retain the prefix write the destination_object as e.g. ``blah/foo``, in
         which case the copied file will be named ``blah/foo/baz``.
-    :type destination_object: str
     :param move_object: When move object is True, the object is moved instead of copied to the new location.
         This is the equivalent of a mv command as opposed to a cp command.
-    :type move_object: bool
     :param gcp_conn_id: (Optional) The connection ID used to connect to Google Cloud.
-    :type gcp_conn_id: str
     :param delegate_to: The account to impersonate using domain-wide delegation of authority,
         if any. For this to work, the service account making the request must have
         domain-wide delegation enabled.
-    :type delegate_to: str
     :param impersonation_chain: Optional service account to impersonate using short-term
         credentials, or chained list of accounts required to get the access_token
         of the last account in the list, which will be impersonated in the request.
@@ -81,7 +77,6 @@ class GCSToGoogleDriveOperator(BaseOperator):
         If set as a sequence, the identities from the list must grant
         Service Account Token Creator IAM role to the directly preceding identity, with first
         account from the list granting this role to the originating account (templated).
-    :type impersonation_chain: Union[str, Sequence[str]]
     """
 
     template_fields: Sequence[str] = (
@@ -97,11 +92,10 @@ class GCSToGoogleDriveOperator(BaseOperator):
         *,
         source_bucket: str,
         source_object: str,
-        destination_object: Optional[str] = None,
+        destination_object: str | None = None,
         move_object: bool = False,
         gcp_conn_id: str = "google_cloud_default",
-        delegate_to: Optional[str] = None,
-        impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
+        impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
     ) -> None:
         super().__init__(**kwargs)
@@ -111,21 +105,18 @@ class GCSToGoogleDriveOperator(BaseOperator):
         self.destination_object = destination_object
         self.move_object = move_object
         self.gcp_conn_id = gcp_conn_id
-        self.delegate_to = delegate_to
         self.impersonation_chain = impersonation_chain
-        self.gcs_hook = None  # type: Optional[GCSHook]
-        self.gdrive_hook = None  # type: Optional[GoogleDriveHook]
+        self.gcs_hook: GCSHook | None = None
+        self.gdrive_hook: GoogleDriveHook | None = None
 
-    def execute(self, context: 'Context'):
+    def execute(self, context: Context):
 
         self.gcs_hook = GCSHook(
             gcp_conn_id=self.gcp_conn_id,
-            delegate_to=self.delegate_to,
             impersonation_chain=self.impersonation_chain,
         )
         self.gdrive_hook = GoogleDriveHook(
             gcp_conn_id=self.gcp_conn_id,
-            delegate_to=self.delegate_to,
             impersonation_chain=self.impersonation_chain,
         )
 
